pub type Stopped = Clock<StoppedClock>;Expand description
The stopped clock. It returns always the same fixed time.
Aliased Type
pub struct Stopped { /* private fields */ }Trait Implementations
Sourceimpl Stopped for Stopped
impl Stopped for Stopped
Sourcefn local_set(unix_time: &DurationSinceUnixEpoch)
fn local_set(unix_time: &DurationSinceUnixEpoch)
It sets the clock to a given time.
Sourcefn local_set_to_app_start_time()
fn local_set_to_app_start_time()
It sets the clock to the time the application started.
Sourcefn local_set_to_system_time_now()
fn local_set_to_system_time_now()
It sets the clock to the current system time.
Sourcefn local_add(duration: &Duration) -> Result<(), IntErrorKind>
fn local_add(duration: &Duration) -> Result<(), IntErrorKind>
It adds a
Duration to the clock. Read moreSourcefn local_sub(duration: &Duration) -> Result<(), IntErrorKind>
fn local_sub(duration: &Duration) -> Result<(), IntErrorKind>
It subtracts a
Duration from the clock. Read moreSourcefn local_reset()
fn local_reset()
It resets the clock to default fixed time that is application start time (or the unix epoch when testing).
Sourcefn local_set_to_unix_epoch()
fn local_set_to_unix_epoch()
It sets the clock to the Unix Epoch.