It contains a static variable that is set to the time at which the application started.
Statics
- TIME_
AT_ APP_ START - The time at which the application started.
It contains a static variable that is set to the time at which the application started.